@@ -56,10 +56,12 @@ def module_contains_display(expression):
         contains_display_attr = False
     contains_display_func = False
     for arg in expression.value.args:
+        print(arg)
         if isinstance(arg, astroid.nodes.Call):
+            print(arg.func)
+            print(arg.func.attrname)
             if arg.func.attrname == "display":
                 contains_display_func = True
-    print(contains_display_func)
     return (
         contains_func_attribute and contains_attrname and contains_display_attr
     ) or (contains_func_attribute and contains_display_func)
@@ -91,7 +93,10 @@ def module_contains_print(expression):
     #     contains_display_attr = False
     contains_print_func = False
     for arg in expression.value.args:
+        print(arg)
         if isinstance(arg, astroid.nodes.Call):
+            print(arg.func)
+            print(arg.func.attrname)
             if arg.func.attrname == "print":
                 contains_print_func = True
     return contains_func_attribute and contains_print_func
